import { defineConfig, presetWind4, presetTypography, presetWebFonts } from 'unocss';
import { presetFluid } from 'unocss-preset-fluid';

export default defineConfig({
  presets: [
    presetWind4(),
    /**
     *  Fluid spacing and typography.
     *
     *  https://renatomoor.github.io/unocss-preset-fluid/
     */
    presetFluid({
      maxWidth: 1024,
      minWidth: 368,
      extendMaxWidth: 1200,
      extendMinWidth: 320,
      remBase: 16,
      useRemByDefault: false,
      ranges: {
        /* Minor third scale */
        xs: [12.5, 14.16666667],
        sm: [15, 17],
        md: [18, 20.4],
        lg: [21.6, 24.8],
        xl: [25.92, 29.376],
        '2xl': [31.104, 35.2512],
        '3xl': [37.3248, 42.30144],
        /* Single column width */
        page: [368, 640]
      },
      commentHelpers: true,
    }),
    /* Add Inter font */
    presetWebFonts({
      fonts: {
        inter: ['Inter']
      },
      themeKey: 'font'
    }),
    presetTypography({
      selectorName: 'text-formatted'
    })
  ],
  shortcuts: {
    /* Override .border utility */
    /* By default, .border is just border-width: 1px. */
    /* This sets a default .border style of 1px solid black. */
    'border': 'border-1 border-solid border-black',
    /* Override .container utility */
    /* By default, .container is the minimum width of the current breakpoint. */
    /* This sets a max width of md (768px) and centers the container. */
    'container': 'f-max-w-page mx-auto',
    'd-block': 'block' // Alternative class for display: block.
  },
  blocklist: [
    'block' // Block class is used in Drupal templates, admin block table.
  ],

  /* Extract utility classes from templates. */
  content: {
    filesystem: [
      'templates/**/*.twig',
      'components/**/*.twig',
      'layouts/**/*.twig'
    ]
  },
})
