# Vite Dev Server

When the vite dev server is running, code changes are automatically reloaded in the browser.

Configuration is specific to the environment, requiring settings for the container, Vite module settings, and vite configuration.

Start the vite dev server inside the container, and clear caches to load libraries from vite.

You should see ```[vite] connecting...``` and ```[vite] connected.``` in your browser console.

Start dev server:
```npm run dev```

# Vite Module
https://www.drupal.org/project/vite

Install and configure $config['vite']['devServerUrl'] = 'VITE_DEV_URL' in settings.local.php.
Configuring in local settings prevents Drupal from checking for the vite dev server in other environments.
By default, the vite module will check for vite running at http://localhost:5173, vite's default port.

# DDEV Config

Copy config.vite.yaml from this theme into /.ddev/config.vite.yaml.
Or copy the and paste the snippet below.

Copy vite.conf from this theme into /.ddev/nginx_full/vite.conf.

__.ddev/config.vite.yaml__

```yaml
# Copy to .ddev/config.vite.yaml

# vite.SITENAME.ddev.site
additional_hostnames:
  - vite.SITENAME

# Expose vite port
web_extra_exposed_ports:
  - name: vite
    container_port: 5173
    http_port: 5172
    https_port: 5173
```

__.ddev/nginx_full/vite.conf__
```nginx
# Copy to .ddev/nginx_full/vite.conf.

server {
    listen 80;
    listen 443 ssl;

    # Change SITENAME.
    server_name vite.SITENAME.ddev.site;

    ssl_certificate /etc/ssl/certs/master.crt;
    ssl_certificate_key /etc/ssl/certs/master.key;

    location / {
        proxy_pass http://localhost:5173;
        proxy_set_header Host $host;
        proxy_set_header X-Real-IP $remote_addr;
        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
        proxy_set_header X-Forwarded-Proto $scheme;
        proxy_set_header Upgrade $http_upgrade;
        proxy_set_header Connection "upgrade";
        proxy_http_version 1.1;
    }
}
```

# Lando Config

Browser SSL warnings without an exception will cause a CORS error.

Visit the https://vite.SITENAME.lndo.site url and allow an exception.

Or add ~/.lando/certs/LandoCA.cert to your browser's authority certificates.

Copy the code below into your .lando.yml file, or use the .lando.yml file in this theme.

__.lando.yml__
```yaml
# Add vite service container.
services:
  vite:
    type: node:20 # Node version.
    ssl: true # Support SSL.
    sslExpose: false # Don't expose SSL port.
    port: 5173 # Default vite url.
    scanner: false # Don't scan on boot.
    
# Proxy container url to vite port.
proxy:
  vite:
    - vite.SITENAME.lndo.site:5173

# npm, vite commands
tooling:
  npm:
    service: vite
    description: Run npm inside lando.
    cmd: npm
  vite:
    service: vite
    cwd: /app/web/themes/custom/landovite
    cmd:
      - npm i -D
      - npm run dev
```

# Notes
```npm run dev``` command changed to ```vite --host``` in package.json to enable network binding in docker.